# Copy last Speech to clipboard
# BitGlow<ABitGlow@outlook.com>

from . import utility
import api
import os
import globalPluginHandler
from scriptHandler import script
import speech
from speechViewer import SPEECH_ITEM_SEPARATOR
import ui
from versionInfo import version_year

speechModule = speech.speech if version_year>=2021 else speech

class GlobalPlugin(globalPluginHandler.GlobalPlugin):
	def __init__(self, *args, **kwargs):
		super(GlobalPlugin, self).__init__(*args, **kwargs)
		self.lastSpeechText = ''
		self.oldSpeak = speechModule.speak
		speechModule.speak = self.interceptSpeak

	def interceptSpeak(self, sequence, *args, **kwargs):
		self.oldSpeak(sequence, *args, **kwargs)
		self.lastSpeechText = SPEECH_ITEM_SEPARATOR.join([x for x in sequence if isinstance(x, str)])

	@script(
		description=_("将最后一次语音提示复制到剪切板"),
		gesture="kb:NVDA+x"
	)
	def script_copyLastSpeech(self, gesture):
		api.copyToClip(self.lastSpeechText)
		self.oldSpeak('复制朗读到剪切板')

	@script(
		description=_("将最后一次语音提示追加到剪切板"),
		gesture="kb:NVDA+d"
	)
	def script_appendLastSpeech(self, gesture):
		oldText = utility.getClipText()
		api.copyToClip(oldText + os.linesep + self.lastSpeechText if oldText else self.lastSpeechText)
		self.oldSpeak("追加朗读到剪切板")

	@script(
		description=_("尝试打开URL"),
		gesture="kb:NVDA+g"
	)
	def script_tryOpenUrl(self, gesture):
		if not (utility.tryOpenURL(self.lastSpeechText) or utility.tryOpenURL(utility.getClipText())):
			ui.message("未找到可供打开的 URL")

	def terminate(self, *args, **kwargs):
		speechModule.speak = self.oldSpeak
		super().terminate(*args, **kwargs)
